@@ -76,7 +76,7 @@
  * URL:
  *   http://modurl.kldp.net/
  *
- * $Id: mod_url.c,v 1.16 2008/10/21 11:19:10 oops Exp $
+ * $Id: mod_url.c,v 1.17 2012/01/24 17:18:31 oops Exp $
  */
 
 /*
@@ -255,6 +255,9 @@ void redurl_mem_error (const request_rec * s, const char * file, int line, char
 
 void check_redurl_iconv (request_rec * r, urlconfig * cfg, iconv_s * ic, char * s_uri)
 {
+#ifdef _LIBICONV_H
+	const
+#endif
 	char * src = s_uri;
 	char * to;
 	const char * s_enc, * c_enc;
